Crate datafusion_sqllogictest

Crate datafusion_sqllogictest 

DataFusion sqllogictest driver

Structs

CurrentlyExecutingSqlTracker
Hold the currently executed SQL statements. This is used to save the currently running SQLs in case of a crash.
DataFusion
DataFusionSubstraitRoundTrip
Filter
Filter specification that determines whether a certain sqllogictest record in a certain file should be filtered. In order for a Filter to match a test case:
Postgrespostgres
TestContext
Context for running tests

Enums

DFColumnType
DFSqlLogicTestError
DataFusion sql-logicaltest error

Functions

convert_batches
Converts batches to a result as expected by sqllogictest.
convert_schema_to_types
Converts columns to a result as expected by sqllogicteset.
df_value_validator
Validate the actual and expected values.
is_spark_path
read_dir_recursive
setup_scratch_dir
Sets up an empty directory at test_files/scratch/<name> creating it if needed and clearing any file contents if it exists This allows tests for inserting to external tables or copy to persist data to disk and have consistent state when running a new test
should_skip_file
Given a list of Filters, determines if the whole file in the provided path can be skipped.
should_skip_record
Determines whether a certain sqllogictest record should be skipped given the provided filters.
value_normalizer
Trailing whitespace from lines in SLT will typically be removed, but do not fail if it is not If particular test wants to cover trailing whitespace on a value, it should project additional non-whitespace column on the right.

Type Aliases

DFOutput