pub struct Postgres { /* private fields */ }Available on crate feature
postgres only.Implementations
Sourceimpl Postgres
impl Postgres
Sourcepub async fn connect(
relative_path: PathBuf,
pb: ProgressBar,
) -> Result<Self, Error>
pub async fn connect( relative_path: PathBuf, pb: ProgressBar, ) -> Result<Self, Error>
Creates a runner for executing queries against an existing postgres connection.
relative_path is used for display output and to create a postgres schema.
The database connection details can be overridden by the
PG_URI environment variable.
This defaults to
PG_URI="postgresql://postgres@127.0.0.1/test"See https://docs.rs/tokio-postgres/latest/tokio_postgres/config/struct.Config.html#url for format
Sourcepub async fn connect_with_tracked_sql(
relative_path: PathBuf,
pb: ProgressBar,
currently_executing_sql_tracker: CurrentlyExecutingSqlTracker,
) -> Result<Self, Error>
pub async fn connect_with_tracked_sql( relative_path: PathBuf, pb: ProgressBar, currently_executing_sql_tracker: CurrentlyExecutingSqlTracker, ) -> Result<Self, Error>
Creates a runner for executing queries against an existing postgres connection with a tracker for currently executing SQL statements.
Sourcepub fn with_currently_executing_sql_tracker(
self,
currently_executing_sql_tracker: CurrentlyExecutingSqlTracker,
) -> Self
pub fn with_currently_executing_sql_tracker( self, currently_executing_sql_tracker: CurrentlyExecutingSqlTracker, ) -> Self
Add a tracker that will track the currently executed SQL statement.
This is useful for logging and debugging purposes.