DataFusion sqllogictest driver
Structs
- Currently
Executing SqlTracker - Hold the currently executed SQL statements. This is used to save the currently running SQLs in case of a crash.
- Data
Fusion - Data
Fusion Substrait Round Trip - Filter
- Filter specification that determines whether a certain sqllogictest record in
a certain file should be filtered. In order for a
Filterto match a test case: - Postgres
postgres - Test
Context - Context for running tests
Enums
- DFColumn
Type - DFSql
Logic Test Error - DataFusion sql-logicaltest error
Functions
- convert_
batches - Converts
batchesto a result as expected by sqllogictest. - convert_
schema_ to_ types - Converts columns to a result as expected by sqllogicteset.
- df_
value_ validator - Validate the actual and expected values.
- is_
spark_ path - read_
dir_ recursive - setup_
scratch_ dir - Sets up an empty directory at
test_files/scratch/<name>creating it if needed and clearing any file contents if it exists This allows tests for inserting to external tables or copy to persist data to disk and have consistent state when running a new test - should_
skip_ file - Given a list of
Filters, determines if the whole file in the provided path can be skipped. - should_
skip_ record - Determines whether a certain sqllogictest record should be skipped given the provided filters.
- value_
normalizer - Trailing whitespace from lines in SLT will typically be removed, but do not fail if it is not If particular test wants to cover trailing whitespace on a value, it should project additional non-whitespace column on the right.